pub enum IValidatorConfigV2Errors {
Show 18 variants
AlreadyInitialized(AlreadyInitialized),
IngressAlreadyExists(IngressAlreadyExists),
EmptyV1ValidatorSet(EmptyV1ValidatorSet),
InvalidMigrationIndex(InvalidMigrationIndex),
InvalidOwner(InvalidOwner),
InvalidPublicKey(InvalidPublicKey),
InvalidSignature(InvalidSignature),
InvalidSignatureFormat(InvalidSignatureFormat),
InvalidValidatorAddress(InvalidValidatorAddress),
MigrationNotComplete(MigrationNotComplete),
NotInitialized(NotInitialized),
NotIp(NotIp),
NotIpPort(NotIpPort),
PublicKeyAlreadyExists(PublicKeyAlreadyExists),
Unauthorized(Unauthorized),
AddressAlreadyHasValidator(AddressAlreadyHasValidator),
ValidatorAlreadyDeactivated(ValidatorAlreadyDeactivated),
ValidatorNotFound(ValidatorNotFound),
}Expand description
Container for all the IValidatorConfigV2 custom errors.
Variants
AlreadyInitialized(AlreadyInitialized)
IngressAlreadyExists(IngressAlreadyExists)
EmptyV1ValidatorSet(EmptyV1ValidatorSet)
InvalidMigrationIndex(InvalidMigrationIndex)
InvalidOwner(InvalidOwner)
InvalidPublicKey(InvalidPublicKey)
InvalidSignature(InvalidSignature)
InvalidSignatureFormat(InvalidSignatureFormat)
InvalidValidatorAddress(InvalidValidatorAddress)
MigrationNotComplete(MigrationNotComplete)
NotInitialized(NotInitialized)
NotIp(NotIp)
NotIpPort(NotIpPort)
PublicKeyAlreadyExists(PublicKeyAlreadyExists)
AddressAlreadyHasValidator(AddressAlreadyHasValidator)
ValidatorAlreadyDeactivated(ValidatorAlreadyDeactivated)
ValidatorNotFound(ValidatorNotFound)
Implementations
Sourceimpl IValidatorConfigV2Errors
impl IValidatorConfigV2Errors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IValidatorConfigV2Errors
impl IValidatorConfigV2Errors
pub const fn address_already_has_validator() -> IValidatorConfigV2Errors
pub const fn public_key_already_exists() -> IValidatorConfigV2Errors
pub const fn validator_not_found() -> IValidatorConfigV2Errors
pub const fn validator_already_deactivated() -> IValidatorConfigV2Errors
pub const fn invalid_public_key() -> IValidatorConfigV2Errors
pub const fn invalid_signature() -> IValidatorConfigV2Errors
pub const fn invalid_signature_format() -> IValidatorConfigV2Errors
pub const fn invalid_validator_address() -> IValidatorConfigV2Errors
pub const fn not_initialized() -> IValidatorConfigV2Errors
pub const fn already_initialized() -> IValidatorConfigV2Errors
pub const fn migration_not_complete() -> IValidatorConfigV2Errors
pub const fn empty_v1_validator_set() -> IValidatorConfigV2Errors
pub const fn invalid_migration_index() -> IValidatorConfigV2Errors
pub const fn invalid_owner() -> IValidatorConfigV2Errors
pub fn not_ip(input: String, backtrace: String) -> IValidatorConfigV2Errors
pub fn not_ip_port(input: String, backtrace: String) -> IValidatorConfigV2Errors
pub fn ingress_already_exists(ingress: String) -> IValidatorConfigV2Errors