pub struct IValidatorConfigV2Instance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A IValidatorConfigV2 instance.
Contains type-safe methods for interacting with an on-chain instance of the
IValidatorConfigV2 contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
Sourceimpl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Instantiation and getters/setters.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Instantiation and getters/setters.
Sourcepub const fn new(
address: Address,
__provider: P,
) -> IValidatorConfigV2Instance<P, N>
pub const fn new( address: Address, __provider: P, ) -> IValidatorConfigV2Instance<P, N>
Creates a new wrapper around an on-chain IValidatorConfigV2 contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourcepub fn at(self, address: Address) -> IValidatorConfigV2Instance<P, N>
pub fn at(self, address: Address) -> IValidatorConfigV2Instance<P, N>
Sets the address and returns self.
Sourceimpl<P, N> IValidatorConfigV2Instance<&P, N>where
P: Clone,
impl<P, N> IValidatorConfigV2Instance<&P, N>where
P: Clone,
Sourcepub fn with_cloned_provider(self) -> IValidatorConfigV2Instance<P, N>
pub fn with_cloned_provider(self) -> IValidatorConfigV2Instance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Function calls.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Function calls.
Sourcepub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn getActiveValidators(
&self,
) -> CallBuilder<&P, PhantomData<getActiveValidatorsCall>, N>
pub fn getActiveValidators( &self, ) -> CallBuilder<&P, PhantomData<getActiveValidatorsCall>, N>
Creates a new call builder for the [getActiveValidators] function.
Sourcepub fn getInitializedAtHeight(
&self,
) -> CallBuilder<&P, PhantomData<getInitializedAtHeightCall>, N>
pub fn getInitializedAtHeight( &self, ) -> CallBuilder<&P, PhantomData<getInitializedAtHeightCall>, N>
Creates a new call builder for the [getInitializedAtHeight] function.
Sourcepub fn owner(&self) -> CallBuilder<&P, PhantomData<ownerCall>, N>
pub fn owner(&self) -> CallBuilder<&P, PhantomData<ownerCall>, N>
Creates a new call builder for the [owner] function.
Sourcepub fn validatorCount(
&self,
) -> CallBuilder<&P, PhantomData<validatorCountCall>, N>
pub fn validatorCount( &self, ) -> CallBuilder<&P, PhantomData<validatorCountCall>, N>
Creates a new call builder for the [validatorCount] function.
Sourcepub fn validatorByIndex(
&self,
index: u64,
) -> CallBuilder<&P, PhantomData<validatorByIndexCall>, N>
pub fn validatorByIndex( &self, index: u64, ) -> CallBuilder<&P, PhantomData<validatorByIndexCall>, N>
Creates a new call builder for the [validatorByIndex] function.
Sourcepub fn validatorByAddress(
&self,
validatorAddress: Address,
) -> CallBuilder<&P, PhantomData<validatorByAddressCall>, N>
pub fn validatorByAddress( &self, validatorAddress: Address, ) -> CallBuilder<&P, PhantomData<validatorByAddressCall>, N>
Creates a new call builder for the [validatorByAddress] function.
Sourcepub fn validatorByPublicKey(
&self,
publicKey: FixedBytes<32>,
) -> CallBuilder<&P, PhantomData<validatorByPublicKeyCall>, N>
pub fn validatorByPublicKey( &self, publicKey: FixedBytes<32>, ) -> CallBuilder<&P, PhantomData<validatorByPublicKeyCall>, N>
Creates a new call builder for the [validatorByPublicKey] function.
Sourcepub fn getNextNetworkIdentityRotationEpoch(
&self,
) -> CallBuilder<&P, PhantomData<getNextNetworkIdentityRotationEpochCall>, N>
pub fn getNextNetworkIdentityRotationEpoch( &self, ) -> CallBuilder<&P, PhantomData<getNextNetworkIdentityRotationEpochCall>, N>
Creates a new call builder for the [getNextNetworkIdentityRotationEpoch] function.
Sourcepub fn isInitialized(
&self,
) -> CallBuilder<&P, PhantomData<isInitializedCall>, N>
pub fn isInitialized( &self, ) -> CallBuilder<&P, PhantomData<isInitializedCall>, N>
Creates a new call builder for the [isInitialized] function.
Sourcepub fn addValidator(
&self,
validatorAddress: Address,
publicKey: FixedBytes<32>,
ingress: String,
egress: String,
feeRecipient: Address,
signature: Bytes,
) -> CallBuilder<&P, PhantomData<addValidatorCall>, N>
pub fn addValidator( &self, validatorAddress: Address, publicKey: FixedBytes<32>, ingress: String, egress: String, feeRecipient: Address, signature: Bytes, ) -> CallBuilder<&P, PhantomData<addValidatorCall>, N>
Creates a new call builder for the [addValidator] function.
Sourcepub fn deactivateValidator(
&self,
idx: u64,
) -> CallBuilder<&P, PhantomData<deactivateValidatorCall>, N>
pub fn deactivateValidator( &self, idx: u64, ) -> CallBuilder<&P, PhantomData<deactivateValidatorCall>, N>
Creates a new call builder for the [deactivateValidator] function.
Sourcepub fn rotateValidator(
&self,
idx: u64,
publicKey: FixedBytes<32>,
ingress: String,
egress: String,
signature: Bytes,
) -> CallBuilder<&P, PhantomData<rotateValidatorCall>, N>
pub fn rotateValidator( &self, idx: u64, publicKey: FixedBytes<32>, ingress: String, egress: String, signature: Bytes, ) -> CallBuilder<&P, PhantomData<rotateValidatorCall>, N>
Creates a new call builder for the [rotateValidator] function.
Sourcepub fn setFeeRecipient(
&self,
idx: u64,
feeRecipient: Address,
) -> CallBuilder<&P, PhantomData<setFeeRecipientCall>, N>
pub fn setFeeRecipient( &self, idx: u64, feeRecipient: Address, ) -> CallBuilder<&P, PhantomData<setFeeRecipientCall>, N>
Creates a new call builder for the [setFeeRecipient] function.
Sourcepub fn setIpAddresses(
&self,
idx: u64,
ingress: String,
egress: String,
) -> CallBuilder<&P, PhantomData<setIpAddressesCall>, N>
pub fn setIpAddresses( &self, idx: u64, ingress: String, egress: String, ) -> CallBuilder<&P, PhantomData<setIpAddressesCall>, N>
Creates a new call builder for the [setIpAddresses] function.
Sourcepub fn transferValidatorOwnership(
&self,
idx: u64,
newAddress: Address,
) -> CallBuilder<&P, PhantomData<transferValidatorOwnershipCall>, N>
pub fn transferValidatorOwnership( &self, idx: u64, newAddress: Address, ) -> CallBuilder<&P, PhantomData<transferValidatorOwnershipCall>, N>
Creates a new call builder for the [transferValidatorOwnership] function.
Sourcepub fn transferOwnership(
&self,
newOwner: Address,
) -> CallBuilder<&P, PhantomData<transferOwnershipCall>, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> CallBuilder<&P, PhantomData<transferOwnershipCall>, N>
Creates a new call builder for the [transferOwnership] function.
Sourcepub fn setNetworkIdentityRotationEpoch(
&self,
epoch: u64,
) -> CallBuilder<&P, PhantomData<setNetworkIdentityRotationEpochCall>, N>
pub fn setNetworkIdentityRotationEpoch( &self, epoch: u64, ) -> CallBuilder<&P, PhantomData<setNetworkIdentityRotationEpochCall>, N>
Creates a new call builder for the [setNetworkIdentityRotationEpoch] function.
Sourcepub fn migrateValidator(
&self,
idx: u64,
) -> CallBuilder<&P, PhantomData<migrateValidatorCall>, N>
pub fn migrateValidator( &self, idx: u64, ) -> CallBuilder<&P, PhantomData<migrateValidatorCall>, N>
Creates a new call builder for the [migrateValidator] function.
Sourcepub fn initializeIfMigrated(
&self,
) -> CallBuilder<&P, PhantomData<initializeIfMigratedCall>, N>
pub fn initializeIfMigrated( &self, ) -> CallBuilder<&P, PhantomData<initializeIfMigratedCall>, N>
Creates a new call builder for the [initializeIfMigrated] function.
Sourceimpl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Event filters.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Event filters.
Sourcepub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn ValidatorAdded_filter(&self) -> Event<&P, ValidatorAdded, N>
pub fn ValidatorAdded_filter(&self) -> Event<&P, ValidatorAdded, N>
Creates a new event filter for the ValidatorAdded event.
Sourcepub fn ValidatorDeactivated_filter(&self) -> Event<&P, ValidatorDeactivated, N>
pub fn ValidatorDeactivated_filter(&self) -> Event<&P, ValidatorDeactivated, N>
Creates a new event filter for the ValidatorDeactivated event.
Sourcepub fn ValidatorRotated_filter(&self) -> Event<&P, ValidatorRotated, N>
pub fn ValidatorRotated_filter(&self) -> Event<&P, ValidatorRotated, N>
Creates a new event filter for the ValidatorRotated event.
Sourcepub fn FeeRecipientUpdated_filter(&self) -> Event<&P, FeeRecipientUpdated, N>
pub fn FeeRecipientUpdated_filter(&self) -> Event<&P, FeeRecipientUpdated, N>
Creates a new event filter for the FeeRecipientUpdated event.
Sourcepub fn IpAddressesUpdated_filter(&self) -> Event<&P, IpAddressesUpdated, N>
pub fn IpAddressesUpdated_filter(&self) -> Event<&P, IpAddressesUpdated, N>
Creates a new event filter for the IpAddressesUpdated event.
Sourcepub fn ValidatorOwnershipTransferred_filter(
&self,
) -> Event<&P, ValidatorOwnershipTransferred, N>
pub fn ValidatorOwnershipTransferred_filter( &self, ) -> Event<&P, ValidatorOwnershipTransferred, N>
Creates a new event filter for the ValidatorOwnershipTransferred event.
Sourcepub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
Creates a new event filter for the OwnershipTransferred event.
Sourcepub fn ValidatorMigrated_filter(&self) -> Event<&P, ValidatorMigrated, N>
pub fn ValidatorMigrated_filter(&self) -> Event<&P, ValidatorMigrated, N>
Creates a new event filter for the ValidatorMigrated event.
Sourcepub fn NetworkIdentityRotationEpochSet_filter(
&self,
) -> Event<&P, NetworkIdentityRotationEpochSet, N>
pub fn NetworkIdentityRotationEpochSet_filter( &self, ) -> Event<&P, NetworkIdentityRotationEpochSet, N>
Creates a new event filter for the NetworkIdentityRotationEpochSet event.
Sourcepub fn Initialized_filter(&self) -> Event<&P, Initialized, N>
pub fn Initialized_filter(&self) -> Event<&P, Initialized, N>
Creates a new event filter for the Initialized event.
Sourcepub fn SkippedValidatorMigration_filter(
&self,
) -> Event<&P, SkippedValidatorMigration, N>
pub fn SkippedValidatorMigration_filter( &self, ) -> Event<&P, SkippedValidatorMigration, N>
Creates a new event filter for the SkippedValidatorMigration event.